Stan Math Library: stan/math/prim/scal/fun/square.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

square.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_PRIM_SCAL_FUN_SQUARE_HPP
2 #define STAN_MATH_PRIM_SCAL_FUN_SQUARE_HPP
3
4 namespace stan {
5 namespace math {
6
21 template <typename T>
22 inline T square(const T x) {
23 return x * x;
24 }
25
26 }
27 }
28
29 #endif
stan
Definition: log_sum_exp.hpp:8
stan::math::square
fvar< T > square(const fvar< T > &x)
Definition: square.hpp:15

[ Stan Home Page ] © 2011–2016, Stan Development Team.